import logging

import requests


class JiraSite(object):
    def __init__(self, jira_url: str, jira_username: str, jira_password: str,
                 jira_destination: str = None):
        self.jira_destination = jira_destination
        self.jira_url = jira_url.rstrip('/')
        self.jira_username = jira_username
        self.jira_password = jira_password
        self.session = requests.session()

        try:
            self.login()
        except Exception as ex:
            logging.error(ex)
            pass

    def run(self):
        self.session.request(method="GET", url=f'{self.jira_url}/{self.jira_destination}')

    def login(self):
        url = f"{self.jira_url}/login.jsp"
        logging.info(f"attempting login to Jira using url: {url} ")

        payload = f'atl_token=&login=Log%20In&os_destination={self.jira_destination}&os_password={self.jira_password}&os_username={self.jira_username}&user_role='
        headers = {
            'Origin': f'{self.jira_url}',
            'Upgrade-Insecure-Requests': '1',
            'DNT': '1',
            'Content-Type': 'application/x-www-form-urlencoded',
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.130 Safari/537.36',
            'Sec-Fetch-User': '?1',
            'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9'
        }

        response = self.session.request("POST", url, headers=headers, data=payload)
        logging.debug(response.text.encode('utf8'))
        # if response.status_code != 302:
        #     raise AuthenticationException()



import logging

import requests


class ConfluenceSite(object):
    def __init__(self, confluence_url: str, confluence_username: str, confluence_password: str,
                 confluence_target_space: str
                 ):
        self.confluence_url = confluence_url.rstrip('/')
        self.confluence_username = confluence_username
        self.confluence_password = confluence_password
        if confluence_target_space is not None:
            self.confluence_target_space = confluence_target_space.lstrip('/')
        else:
            self.confluence_target_space = None
        self.cookies = None
        self.session = requests.session()
        self.login()

    def run(self):
        response = self.session.request(method="GET",
                                        url=f'{self.confluence_url}/display/{self.confluence_target_space}',
                                        cookies=self.session.cookies)
        logging.debug(response.text.encode('utf8'))

    def login(self):
        url = f"{self.confluence_url}/dologin.action"
        logging.info(f"attempting login to Confluence using url: {url} ")

        payload = f'login=Log%20in&os_destination=&os_password={self.confluence_password}&os_username={self.confluence_username}'
        headers = {
            'Origin': f'{self.confluence_url}',
            'Upgrade-Insecure-Requests': '1',
            'DNT': '1',
            'Content-Type': 'application/x-www-form-urlencoded',
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.130 Safari/537.36',
            'Sec-Fetch-User': '?1',
            'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9'
        }
        response = self.session.request("POST", url, headers=headers, data=payload)
        logging.debug(response.text.encode('utf8'))

        self.cookies = response.cookies  # save cookies
        logging.debug(response.cookies)
        # if response.status_code != 302:
        #     raise AuthenticationException()



import logging
import sys
from argparse import ArgumentParser, Namespace

from atl_cache_warmer.ConfluenceSite import ConfluenceSite
from atl_cache_warmer.JiraSite import JiraSite


def create_arg_parser() -> ArgumentParser:
    parser: ArgumentParser = ArgumentParser()
    parser.add_argument('-u',
                        dest="username",
                        type=str,
                        help="username to use",
                        required=True)
    parser.add_argument('-p',
                        dest="password",
                        type=str,
                        help="password to use",
                        required=True)
    parser.add_argument('-j',
                        dest='jira_url',
                        type=str,
                        help="url for jira",
                        default=None)
    parser.add_argument('-t',
                        dest="jira_target",
                        type=str,
                        help="path in jira to make request to",
                        default=None
                        )
    parser.add_argument('-c',
                        dest='confluence_url',
                        help="url for confluence",
                        type=str,
                        default=None)
    parser.add_argument('-s',
                        dest="space",
                        help="confluence space to make request to",
                        type=str,
                        default=None)
    parser.add_argument('-v',
                        dest="verbosity",
                        help="Increase verbosity level, can used up to 2 times",
                        action="count",
                        default=0)

    return parser


def main():
    arg_parser = create_arg_parser()
    parsed_args: Namespace = arg_parser.parse_args(sys.argv[1:])
    log_level = logging.ERROR
    if parsed_args.verbosity == 0:
        log_level = logging.WARNING
    elif parsed_args.verbosity == 1:
        log_level = logging.INFO
    elif parsed_args.verbosity == 2:
        log_level = logging.DEBUG
    logging.basicConfig(
        level=log_level
    )
    if parsed_args.confluence_url is not None:
        try:
            c = ConfluenceSite(confluence_url=parsed_args.confluence_url,
                               confluence_username=parsed_args.username,
                               confluence_password=parsed_args.password,
                               confluence_target_space=parsed_args.space
                               )
            c.run()
        except Exception as ex:
            logging.error(ex)
            pass

    if parsed_args.jira_url is not None:

        try:
            j = JiraSite(jira_url=parsed_args.jira_url,
                         jira_username=parsed_args.username,
                         jira_password=parsed_args.password,
                         jira_destination=parsed_args.jira_target)
            j.run()
        except Exception as ex:
            logging.error(ex)
            pass



from os import path

import setuptools

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_descr = f.read()

setuptools.setup(
    name='atl_cache_warmer',
    version='0.11',
    packages=['atl_cache_warmer'],
    entry_points={
        'console_scripts': [
            'atlwarmer = atl_cache_warmer.cache_builder:main'
        ]
    },
    url='https://github.com/np-at/atl_cache_warmer',
    long_description=long_descr,
    long_description_content_type='text/markdown',
    license='MIT',
    author='np-at',
    author_email='noahpraskins@gmail.com',
    description='Little script to warm up confluence and jira caches to make it more responsive',
    install_requires=['requests'],
    python_requires='>=3.6'
)
